# Step 6: Track and Report
### On this page
  * [Create a Custom Dashboard for AI Governance](https://help.sap.com/docs/leanix/ea/step-6-track-and-report#create-a-custom-dashboard-for-ai-governance)
  * [Use the AI Agent Hub Dashboard](https://help.sap.com/docs/leanix/ea/step-6-track-and-report#use-the-ai-agent-hub-dashboard)
  * [Monitor KPIs for AI Agents on the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/step-6-track-and-report#monitor-kpis-for-ai-agents-on-the-architecture-executive-dashboard)


Track the status of your AI-related initiatives and drive AI adoption.
